Learn R Programming

ggsector (version 1.6.6)

draw_key_sector: draw_key_sector

Description

draw_key_sector

Usage

draw_key_sector(data, params, size)

Value

ggplot legend

Arguments

data

A single row data frame containing the scaled aesthetics to display in this key

params

A list of additional parameters supplied to the geom.

size

Width and height of key in mm.